ConnectState enum

connectActive 连接正常,正在传输数据 connectIdle 连接正常,超过SSEClient._idleTimeout无数据传输 connectException 连接正常,但是过长时间没有数据传输, 超过SSEClient._exceptionTimeout connectSuspend 连接正常,被客户端挂起了,没有数据传输,这个和connectException做区分,connectException无数据传输是异常情况,但是connectSuspend不是. disconnectRepairing 连接已断开,但是正在进行重试 (保留状态,暂时未使用) disconnectError 连接已断开,已超过重试最大次数 disconnectNormal 连接已断开,非异常断开,可能是临时断开,会由程序尝试重新连接

Inheritance
Available extensions

Values

connectActive → const ConnectState
connectIdle → const ConnectState
connectException → const ConnectState
connectSuspend → const ConnectState
disconnectRepairing → const ConnectState
disconnectError → const ConnectState
disconnectNormal → const ConnectState

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isAbnormal() bool
是否异常
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ConnectState>
A constant List of the values in this enum, in order of their declaration.