DeliverRep class final

Interceptor chain disposed sse will return SSEResponse , SSEResponse will convert to DeliverRep, DeliverRep will convert to PopRep. SSEResponse -> DeliverRep - PopRep Each step have a little extra data for bride multiple module. SSEResponse : Meaning interceptor disposed result. DeliverRep : Meaning interceptor manager disposed result. PopRep : Provide to SSECacheDeliverer

Constructors

DeliverRep(SSEResponse sseResponse, List<SSEInterceptor> notifiedInterceptors)

Properties

hashCode int
The hash code for this object.
no setterinherited
notifiedInterceptors List<SSEInterceptor>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sseResponse SSEResponse
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited