ISSEStream class abstract

Constructors

ISSEStream()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Close sse stream
destroy() → void
inherited
isTransforming() → RxBool
SSE stream is transforming
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open({Future<void> onOpened()?, dynamic onSuccess()?, Future<void> onDone(List<ServerSentEvent> sseList)?, Future<void> onReceive(ServerSentEvent event)?, dynamic onError(Object error)?, RequestOptions? requestOptions}) → void
Open a sse stream onOpened First chunk data received will call it onSuccess Stream open success callback onDone Call back when stream transition done onReceive After receive stream data and transform to ServerSentEvent callback onError Open fail or transform process throw error callback requestOptions If stream from network request, This parameter represents its request RequestOptions But is not, it will be null.
reset() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited