isOfflineStream method

bool isOfflineStream()

Check request is return by offline stream.

If offlineProvider is here, it proves that the data is obtained from the client and there is no need to make a network request.

Implementation

bool isOfflineStream() {
  return extra['offlineProvider'] != null;
}