isStream method
Note that this function only prove request is streaming data , and not doesn't mean return is streaming data.
Implementation
bool isStream() {
return headers["Accept"] == 'text/event-stream';
}
Note that this function only prove request is streaming data , and not doesn't mean return is streaming data.
bool isStream() {
return headers["Accept"] == 'text/event-stream';
}