SSEChain class final

SSE chain of responsibility for distribution to the corresponding interceptor

Constructors

SSEChain(List<SSEInterceptor> _sseInterceptors)

Properties

hashCode int
The hash code for this object.
no setterinherited
notifiedInterceptors List<SSEInterceptor>
List of interceptors that have been notified
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInterceptors() List<SSEInterceptor>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
proceed(SSEResponse response) SSEResponse
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

tag → const String