watchEvents property
Need to watch event set, Events that are not included in the list are not intercept
Implementation
Set<WatchEvent> watchEvents;
Need to watch event set, Events that are not included in the list are not intercept
Set<WatchEvent> watchEvents;