onMatchChain property
Callback when match event to interceptor. (Currently, it is similar to the intercept function SSEInterceptor.intercept)
Implementation
Function(String name, String? eleType)? onMatchChain;
Callback when match event to interceptor. (Currently, it is similar to the intercept function SSEInterceptor.intercept)
Function(String name, String? eleType)? onMatchChain;