SSEInterceptorManager class final

Constructors

SSEInterceptorManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addSSEInterceptor(SSEInterceptor interceptor, {bool isOnly = false}) bool
SSE cache pool will deliver sse that matched SSEInterceptor.watchEvents to SSEInterceptor.intercept return result represent is add success, true is added to chain, false is not.
deliver(ServerSentEventCache event, {bool isPeek = false}) DeliverRep
Deliver cache event steps
destroy() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSSEInterceptor(SSEInterceptor interceptor) → void
removeStreamInterceptor() → void
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

tag → const String