addConnectStateObserver method
Add observer listen connection change More detail state refer ConnectState
Implementation
void addConnectStateObserver(SSEConnectObserver observer) {
_connectManager.addConnectStateObserver(observer);
}
Add observer listen connection change More detail state refer ConnectState
void addConnectStateObserver(SSEConnectObserver observer) {
_connectManager.addConnectStateObserver(observer);
}