sseConfig property
SSEProcessorConfig
get
sseConfig
This method is used within the module and needs to ensure that it is not null. If there is an external call involved, the isInit method needs to be called first to check the status.
Implementation
SSEProcessorConfig get sseConfig {
return _sseConfig!;
}