sseProcessorFactory property
The application usually uses the sseProcessorFactory object create a SSEProcessor to receive sse events, because the early theater only runs one, usually only one SSEProcessor, so the structure is designed according to the singleton, currently for multiple theater situations, still want to extend the singleton use mode, to avoid major changes.
Implementation
static SSEProcessorFactory? sseProcessorFactory;