SSEResponse class

Constructors

SSEResponse({required ServerSentEvent event, bool removeCache = false, bool autoRemove = true, String reqUrl = ""})

Properties

autoRemove bool
If remove auto remove from cache pool. (This flag is valid only if removeCache is false) true is automatic remove, according to last consumed time stamp match false don't automatic remove until interceptor consume it
getter/setter pair
event ServerSentEvent
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
removeCache bool
If remove from cache pool
getter/setter pair
reqUrl String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited