ServerSentEventCache class final

Constructors

ServerSentEventCache(ServerSentEvent cache, String reqUrl)

Properties

autoRemove bool
Whether to automatically remove from the cache, true is to automatically remove, based on the timeline match of the last consumption, false will not automatically remove and need to wait until the consumption is blocked)
getter/setter pair
cache ServerSentEvent
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isDirty bool
getter/setter pair
notifiedSSEListener Set<SSEInterceptor>
A notified listening, to prevent duplicate notifications
getter/setter pair
reqUrl String
SSE api request url
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeStamp int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited