SseOfflineProvider class abstract

This class provides offline SSE distribution functionality.

Most of the time, SSE is sent from the server side, However , sometimes the client generates some data and wants to use the SSE distribution function of the client side.

Constructors

SseOfflineProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOfflineStream() ISSEStream
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited