StreamBundle class

It's used to cache bytes stream from native, bytesBuffer is cache real data from native stream. StreamBundle corresponding to streamId which is native stream and flutter bridge stream relationship unique id. StreamId and StreamBundle related to SSEBridge.streamBufferMaps. isEnd is flag that represent native stream end. Which set ture when receive a string SSEBridge.streamEndFlag from native stream. isError is flag represent native stream throw error when transforming.

Constructors

StreamBundle()

Properties

bytesBuffer List<int>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isEnd bool
getter/setter pair
isError bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() StreamBundle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited