WatchEvent class

Constructors

WatchEvent(String eventType, {String? matchContent, WatchPriority? priority})

Properties

eventType String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
matchContent String?
Used to match content in ServerSentEvent.result (Both event type and event content matched will be delivered, Not specifying means ignoring content matching)
getter/setter pair
priority WatchPriority
SSE deliver priority, Multiple interceptors watch a same event, priority distribution to high priority interceptor processing. For example : A and B interceptor receive C event simultaneously, A interceptor watch C event priority is Priority.high, but B interceptor watch C event priority is Priority.middle This will be prioritized send event to interceptor A, if A interceptor removed C event from cache pool, C event will not be received in B interceptor. Default value Priority.low
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited