matchContent property
Used to match content in ServerSentEvent.result (Both event type and event content matched will be delivered, Not specifying means ignoring content matching)
Implementation
String? matchContent;
Used to match content in ServerSentEvent.result (Both event type and event content matched will be delivered, Not specifying means ignoring content matching)
String? matchContent;