priority property

WatchPriority priority
getter/setter pair

SSE deliver priority, Multiple interceptors watch a same event, priority distribution to high priority interceptor processing. For example : A and B interceptor receive C event simultaneously, A interceptor watch C event priority is Priority.high, but B interceptor watch C event priority is Priority.middle This will be prioritized send event to interceptor A, if A interceptor removed C event from cache pool, C event will not be received in B interceptor. Default value Priority.low

Implementation

late WatchPriority priority;