Interceptor chain disposed sse will return SSEResponse , SSEResponse will convert to DeliverRep, DeliverRep will convert to PopRep.
SSEResponse -> DeliverRep - PopRep
Each step have a little extra data for bride multiple module.
SSEResponse : Meaning interceptor disposed result.
DeliverRep : Meaning interceptor manager disposed result.
PopRep : Provide to SSECacheDeliverer
A router that responsible for route stream data from native (Android or Ios) to corresponding SSEBridge object in registers.
Because stream data depend native platform transforming, flutter end don't know which is which for multiple SSEBridge exist.
It is possible to know how to distribute to the corresponding SSEBridge through the NativeStreamRouter.
Purpose for convert a sse object to multiple sse objects.
Client receive server sse maybe is whole message in theater situation,
program need to slice it to one after one char to mock printer effect.
Stream raw data to ServerSentEvent data structure when transforming from server.
SSEProcessor support custom transform process.
There is SSEStreamAdapterDefault will use if don't set StreamAdapter outside.
It's used to cache bytes stream from native, bytesBuffer is cache real data from native stream.
StreamBundle corresponding to streamId which is native stream and flutter bridge stream relationship unique id.
StreamId and StreamBundle related to SSEBridge.streamBufferMaps.
isEnd is flag that represent native stream end. Which set ture when receive a string SSEBridge.streamEndFlag from native stream.
isError is flag represent native stream throw error when transforming.
Interceptor clear strategy
round At an round interaction process don't automatic destruction (Destruction after reset) Deprecated.
stream Automatic destroy interceptor when stream done, this is a relatively recommended way than full type.