Open a sse stream
onOpened First chunk data received will call it
onSuccess Stream open success callback
onDone Call back when stream transition done
onReceive After receive stream data and transform to ServerSentEvent callback
onError Open fail or transform process throw error callback
requestOptions If stream from network request, This parameter represents its request RequestOptions
But is not, it will be null.