NativeStreamRouter class
A router that responsible for route stream data from native (Android or Ios) to corresponding SSEBridge object in registers. Because stream data depend native platform transforming, flutter end don't know which is which for multiple SSEBridge exist. It is possible to know how to distribute to the corresponding SSEBridge through the NativeStreamRouter.
Constructors
- NativeStreamRouter()
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
receive(
Map map) → void - Very simple route strategy, will optimize this function later.
-
register(
SSEBridge bridge) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unRegister(
SSEBridge bridge) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited