SSEBridge class final
Native to Flutter Stream Cache
- Inheritance
-
- Object
- ChangeNotifier
- SSEBridge
Properties
- debugTag ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isWorking → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
streamBufferMaps
→ Map<
String, StreamBundle> -
latefinal
- waitBufferCompleter ↔ Completer?
-
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
destroy(
) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
extract(
String streamId) → StreamBundle? -
init(
) → void -
nativeStream(
String streamId) → Stream< Uint8List> - This function used to read from streamBufferMaps in stream format. Create a new stream that transform stream from native.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
offWork(
) → void -
receive(
Map map) → void - This receive stream data from native, put them in streamBufferMaps
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
work(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- streamEndFlag → const String
- streamErrorFlag → const String