SSEConnectObserver class
Connection state observer name Tag name,Only used for print troubleshooting in log priority Notify priority , Connection state change event will prioritize notify to observers, built in : NotifyPriority.high NotifyPriority.middle NotifyPriority.low You can also custom priority by set NotifyPriority.value onConnectStateChange More detail value ref ConnectState, If return true, Don't be sent to subsequent observers, If return false will continue send.
- Implemented types
Constructors
- SSEConnectObserver(String name, NotifyPriority priority, bool onConnectStateChange(ConnectState state))
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- onConnectStateChange ↔ bool Function(ConnectState state)
-
getter/setter pair
- priority ↔ NotifyPriority
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareTo(
SSEConnectObserver other) → int -
Compares this object to another object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited