SSEFilter class abstract
Purpose for convert a sse object to multiple sse objects. Client receive server sse maybe is whole message in theater situation, program need to slice it to one after one char to mock printer effect.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
ServerSentEvent sse) → Future< List< ServerSentEvent> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited