SSEInterceptor class
Constructors
-
SSEInterceptor(Set<
WatchEvent> watchEvents, SSEResponse intercept(SSEChain chain, SSEResponse response), {AutoClearStrategy autoClearStrategy = AutoClearStrategy.stream, String name = "unknown", SSEInterceptorLifeCycle? lifeCycle, bool goThrough = false, bool isPeek = false})
Properties
- autoClearStrategy ↔ AutoClearStrategy
-
Interceptor clear strategy
getter/setter pair
- curWatchEvent ↔ WatchEvent?
-
The event that is currently being processed
getter/setter pair
- goThrough ↔ bool
-
Is must be bypass interceptor, If set true even return SSEResponse directly in other interceptors in chain also will callback in this interceptor.
getter/setter pair
- hasDestroy ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- intercept ↔ SSEResponse Function(SSEChain chain, SSEResponse response)
-
SSE intercept callback,return:
SSEResponse
getter/setter pair
- isPeek ↔ bool
-
Interceptor (isPeek true)
/
| (Server) -----> (Cache pool) -----> Interceptor (isPeek false)getter/setter pair - lifeCycle ↔ SSEInterceptorLifeCycle?
-
Interceptor lifecycle callback
getter/setter pair
- name ↔ String
-
Module name, At present, it is mainly used for troubleshooting
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
watchEvents
↔ Set<
WatchEvent> -
Need to watch event set, Events that are not included in the list are not intercept
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited