SSEInterceptorLifeCycle class
SSE Interceptor lifecycle. onCreate | onMatchChain | onDestroy
Constructors
- SSEInterceptorLifeCycle({dynamic onDestroy(String name)?, dynamic onCreate(String name)?, dynamic onMatchChain(String name, String? eleType)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCreate ↔ dynamic Function(String name)?
-
Callback when created interceptor and add to chain(interceptor list).
getter/setter pair
- onDestroy ↔ dynamic Function(String name)?
-
Callback when interceptor destroyed.
getter/setter pair
- onMatchChain ↔ dynamic Function(String name, String? eleType)?
-
Callback when match event to interceptor. (Currently, it is similar to the intercept function SSEInterceptor.intercept)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited