fastLoadInterval constant
int
const fastLoadInterval
Warning : This value couldn't set too small (maybe 0 or 1), if set too small will lead to stream end quickly,
when stream end will remove all interceptors that type is AutoClearStrategy.stream or AutoClearStrategy.streamAndFull
these interceptors remove early lead to loss useful data that they want to receive.
Implementation
static const fastLoadInterval = 10;