autoRemove property
Whether to automatically remove from the cache, true is to automatically remove, based on the timeline match of the last consumption, false will not automatically remove and need to wait until the consumption is blocked)
Implementation
bool autoRemove = true;