StreamAdapter class abstract
Stream raw data to ServerSentEvent data structure when transforming from server.
SSEProcessor support custom transform process.
There is SSEStreamAdapterDefault will use if don't set StreamAdapter outside.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
destroy(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onConvert(
String raw) → List< ServerSentEvent> -
rawis raw data from stream, implementer should convert it to sse format. -
reset(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited