StreamBundle class
It's used to cache bytes stream from native, bytesBuffer is cache real data from native stream. StreamBundle corresponding to streamId which is native stream and flutter bridge stream relationship unique id. StreamId and StreamBundle related to SSEBridge.streamBufferMaps. isEnd is flag that represent native stream end. Which set ture when receive a string SSEBridge.streamEndFlag from native stream. isError is flag represent native stream throw error when transforming.
Constructors
Properties
Methods
-
copy(
) → StreamBundle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited